@@ -199,8 +199,6 @@ func newWebDAV(ctx context.Context, f fs.Fs, opt *Options) (w *WebDAV, err error
 		router.Method(method, "/*", w)
 	}
 
-	w.Server.Serve()
-
 	return w, nil
 }
 
@@ -237,6 +235,9 @@ func (w *WebDAV) ServeHTTP(rw http.ResponseWriter, r *http.Request) {
 		w.serveDir(rw, r, remote)
 		return
 	}
+	// Add URL Prefix back to path since webdavhandler needs to
+	// return absolute references.
+	r.URL.Path = w.opt.HTTP.BaseURL + r.URL.Path
 	w.webdavhandler.ServeHTTP(rw, r)
 }
 
