@@ -3,7 +3,7 @@ package vfs
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"os"
 	"testing"
 
@@ -17,25 +17,24 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
-func fileCreate(t *testing.T, mode vfscommon.CacheMode) (r *fstest.Run, vfs *VFS, fh *File, item fstest.Item, cleanup func()) {
+func fileCreate(t *testing.T, mode vfscommon.CacheMode) (r *fstest.Run, vfs *VFS, fh *File, item fstest.Item) {
 	opt := vfscommon.DefaultOpt
 	opt.CacheMode = mode
 	opt.WriteBack = writeBackDelay
-	r, vfs, cleanup = newTestVFSOpt(t, &opt)
+	r, vfs = newTestVFSOpt(t, &opt)
 
 	file1 := r.WriteObject(context.Background(), "dir/file1", "file1 contents", t1)
-	fstest.CheckItems(t, r.Fremote, file1)
+	r.CheckRemoteItems(t, file1)
 
 	node, err := vfs.Stat("dir/file1")
 	require.NoError(t, err)
 	require.True(t, node.Mode().IsRegular())
 
-	return r, vfs, node.(*File), file1, cleanup
+	return r, vfs, node.(*File), file1
 }
 
 func TestFileMethods(t *testing.T) {
-	r, vfs, file, _, cleanup := fileCreate(t, vfscommon.CacheModeOff)
-	defer cleanup()
+	r, vfs, file, _ := fileCreate(t, vfscommon.CacheModeOff)
 
 	// String
 	assert.Equal(t, "dir/file1", file.String())
@@ -92,8 +91,7 @@ func testFileSetModTime(t *testing.T, cacheMode vfscommon.CacheMode, open bool,
 	if !canSetModTimeValue {
 		t.Skip("can't set mod time")
 	}
-	r, vfs, file, file1, cleanup := fileCreate(t, cacheMode)
-	defer cleanup()
+	r, vfs, file, file1 := fileCreate(t, cacheMode)
 	if !canSetModTime(t, r) {
 		t.Skip("can't set mod time")
 	}
@@ -137,7 +135,7 @@ func testFileSetModTime(t *testing.T, cacheMode vfscommon.CacheMode, open bool,
 	}
 
 	file1 = fstest.NewItem(file1.Path, contents, t2)
-	fstest.CheckItems(t, r.Fremote, file1)
+	r.CheckRemoteItems(t, file1)
 
 	vfs.Opt.ReadOnly = true
 	err = file.SetModTime(t2)
@@ -168,7 +166,7 @@ func fileCheckContents(t *testing.T, file *File) {
 	fd, err := file.Open(os.O_RDONLY)
 	require.NoError(t, err)
 
-	contents, err := ioutil.ReadAll(fd)
+	contents, err := io.ReadAll(fd)
 	require.NoError(t, err)
 	assert.Equal(t, "file1 contents", string(contents))
 
@@ -176,8 +174,7 @@ func fileCheckContents(t *testing.T, file *File) {
 }
 
 func TestFileOpenRead(t *testing.T) {
-	_, _, file, _, cleanup := fileCreate(t, vfscommon.CacheModeOff)
-	defer cleanup()
+	_, _, file, _ := fileCreate(t, vfscommon.CacheModeOff)
 
 	fileCheckContents(t, file)
 }
@@ -217,7 +214,7 @@ func TestFileOpenReadUnknownSize(t *testing.T) {
 	assert.Equal(t, int64(0), fd.Size())
 
 	// check the contents are not empty even though size is empty
-	gotContents, err := ioutil.ReadAll(fd)
+	gotContents, err := io.ReadAll(fd)
 	require.NoError(t, err)
 	assert.Equal(t, contents, gotContents)
 	t.Logf("gotContents = %q", gotContents)
@@ -229,8 +226,7 @@ func TestFileOpenReadUnknownSize(t *testing.T) {
 }
 
 func TestFileOpenWrite(t *testing.T) {
-	_, vfs, file, _, cleanup := fileCreate(t, vfscommon.CacheModeOff)
-	defer cleanup()
+	_, vfs, file, _ := fileCreate(t, vfscommon.CacheModeOff)
 
 	fd, err := file.openWrite(os.O_WRONLY | os.O_TRUNC)
 	require.NoError(t, err)
@@ -249,13 +245,12 @@ func TestFileOpenWrite(t *testing.T) {
 }
 
 func TestFileRemove(t *testing.T) {
-	r, vfs, file, _, cleanup := fileCreate(t, vfscommon.CacheModeOff)
-	defer cleanup()
+	r, vfs, file, _ := fileCreate(t, vfscommon.CacheModeOff)
 
 	err := file.Remove()
 	require.NoError(t, err)
 
-	fstest.CheckItems(t, r.Fremote)
+	r.CheckRemoteItems(t)
 
 	vfs.Opt.ReadOnly = true
 	err = file.Remove()
@@ -263,13 +258,12 @@ func TestFileRemove(t *testing.T) {
 }
 
 func TestFileRemoveAll(t *testing.T) {
-	r, vfs, file, _, cleanup := fileCreate(t, vfscommon.CacheModeOff)
-	defer cleanup()
+	r, vfs, file, _ := fileCreate(t, vfscommon.CacheModeOff)
 
 	err := file.RemoveAll()
 	require.NoError(t, err)
 
-	fstest.CheckItems(t, r.Fremote)
+	r.CheckRemoteItems(t)
 
 	vfs.Opt.ReadOnly = true
 	err = file.RemoveAll()
@@ -277,8 +271,7 @@ func TestFileRemoveAll(t *testing.T) {
 }
 
 func TestFileOpen(t *testing.T) {
-	_, _, file, _, cleanup := fileCreate(t, vfscommon.CacheModeOff)
-	defer cleanup()
+	_, _, file, _ := fileCreate(t, vfscommon.CacheModeOff)
 
 	fd, err := file.Open(os.O_RDONLY)
 	require.NoError(t, err)
@@ -303,8 +296,7 @@ func TestFileOpen(t *testing.T) {
 }
 
 func testFileRename(t *testing.T, mode vfscommon.CacheMode, inCache bool, forceCache bool) {
-	r, vfs, file, item, cleanup := fileCreate(t, mode)
-	defer cleanup()
+	r, vfs, file, item := fileCreate(t, mode)
 
 	if !operations.CanServerSideMove(r.Fremote) {
 		t.Skip("skip as can't rename files")
@@ -340,14 +332,14 @@ func testFileRename(t *testing.T, mode vfscommon.CacheMode, inCache bool, forceC
 	dir := file.Dir()
 
 	// start with "dir/file1"
-	fstest.CheckItems(t, r.Fremote, item)
+	r.CheckRemoteItems(t, item)
 
 	// rename file to "newLeaf"
 	err = dir.Rename("file1", "newLeaf", rootDir)
 	require.NoError(t, err)
 
 	item.Path = "newLeaf"
-	fstest.CheckItems(t, r.Fremote, item)
+	r.CheckRemoteItems(t, item)
 
 	// check file in cache
 	if inCache {
@@ -363,7 +355,7 @@ func testFileRename(t *testing.T, mode vfscommon.CacheMode, inCache bool, forceC
 	require.NoError(t, err)
 
 	item.Path = "dir/file1"
-	fstest.CheckItems(t, r.Fremote, item)
+	r.CheckRemoteItems(t, item)
 
 	// check file in cache
 	if inCache {
